{% extends 'djikiki/base.html' %}

{% block title%}
{{wiki.name}} - Recently Featured Pages 
{% endblock %}

{% block header %}
		<h2><span></span></h2>
		<h1>Recently Featured Pages</h1>	
{% endblock %}

{% block main %}
<ul>
{% for f_page in featured %}
<li>
<a href="{{f_page.page.get_absolute_url}}">{{f_page.page.title}}</a><br />
{{f_page.page.current_revision.html_text|safe|truncatewords_html:30}}
</li>
{% endfor %}
</ul>

<div id="paginate">
{% if has_next %}
<a href="./?page={{next_page}}">Next</a>
{% endif %}
{% if has_previous %}
<a href="./?page={{prev_page}}">Prev</a>
{% endif %}
</div>
{% endblock %}

{% block contextnav %}
{% endblock %}